Tables!

Name | City | Country
--- | --- | ---
Alfred | Berlin | Germany
Joe | San Francisco | United States
Maria | Cancun | Mexico

Name | Age
--- | ---
Alfred | 31
Joe | 35
Maria | 33

Name (last name optional) | Age (in years)
--- | ---
Alfred | 31
Maria Lopez | 33

User Title | Yearly Salary
--- | ---
Alfred White | 120,000
Maria Lopez | 133,000

Clicked:

Color | Font | Style
--- | --- | ---
Red | Arial | Bold
Blue | Helvetica | Underline
Green | Times New Roman | Italic

City | Country | Continent
--- | --- | ---
Paris | France | Europe
Cairo | Egypt | Africa
Tokyo | Japan | Asia

Row Number